@@ -250,7 +250,8 @@ def mass_update(modeladmin, request, queryset):  # noqa
                              updated=updated)
 
     opts = modeladmin.model._meta
-    perm = "{0}.{1}".format(opts.app_label, get_permission_codename('adminactions_massupdate', opts))
+    perm = "{0}.{1}".format(opts.app_label,
+                            get_permission_codename(mass_update.base_permission, opts))
     if not request.user.has_perm(perm):
         messages.error(request, _('Sorry you do not have rights to execute this action'))
         return
@@ -382,3 +383,4 @@ def mass_update(modeladmin, request, queryset):  # noqa
 
 
 mass_update.short_description = _("Mass update")
+mass_update.base_permission = 'adminactions_massupdate'
